Learn R Programming

vectra (version 0.6.2)

glimpse: Get a glimpse of a vectra table

Description

Shows column names, types, and a preview of the first few values without collecting the full result.

Usage

glimpse(x, width = 5L, ...)

Value

Invisible x.

Arguments

x

A vectra_node object.

width

Maximum number of preview rows to fetch (default 5).

...

Ignored.

Examples

Run this code
f <- tempfile(fileext = ".vtr")
write_vtr(mtcars, f)
tbl(f) |> glimpse()
unlink(f)

Run the code above in your browser using DataLab