powered by
Shows column names, types, and a preview of the first few values without collecting the full result.
glimpse(x, width = 5L, ...)
Invisible x.
x
A vectra_node object.
vectra_node
Maximum number of preview rows to fetch (default 5).
Ignored.
f <- tempfile(fileext = ".vtr") write_vtr(mtcars, f) tbl(f) |> glimpse() unlink(f)
Run the code above in your browser using DataLab