| link | R Documentation |
Creates a link descriptor that specifies how to join a dimension table to a fact table via one or more key columns.
link(key, node)
key |
A character vector or named character vector specifying join keys.
Unnamed: same column name in both tables. Named: |
node |
A |
A vectra_link object.
f_obs <- tempfile(fileext = ".vtr")
f_sp <- tempfile(fileext = ".vtr")
write_vtr(data.frame(sp_id = 1:3, value = c(10, 20, 30)), f_obs)
write_vtr(data.frame(sp_id = 1:3, name = c("A", "B", "C")), f_sp)
lnk <- link("sp_id", tbl(f_sp))
unlink(c(f_obs, f_sp))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.