| tbl_xlsx | R Documentation |
Reads a sheet from an Excel workbook into a vectra node for lazy query
execution. The sheet is read into memory via
openxlsx2::read_xlsx() and then converted
to vectra's internal format. Requires the openxlsx2 package.
tbl_xlsx(path, sheet = 1L, batch_size = .DEFAULT_BATCH_SIZE)
path |
Path to an |
sheet |
Sheet to read: either a name (character) or 1-based index
(integer). Default |
batch_size |
Number of rows per batch (default 65536). |
A vectra_node object representing a lazy scan of the sheet.
if (requireNamespace("openxlsx2", quietly = TRUE)) {
f <- tempfile(fileext = ".xlsx")
openxlsx2::write_xlsx(mtcars, f)
node <- tbl_xlsx(f)
node |> filter(cyl == 6) |> collect()
unlink(f)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.